@@ -21,22 +21,22 @@ $obj->addRegion(  "name" => $region2, "top" => 40, "left" => 85,
 $obj->addMedia( "type" => "audio",
 	       "src" => "rtsp://realserver/g2audio.rm" );
 
-$obj->startSequence();
+$obj->startSequence( repeat => 100 );
 $obj->addSwitchedMedia( "switch" => 'system-bitrate',
 		       'medias' => 
 		       [ { 'region' => $region1,
 			   'switch-target' => 28000,
-			   "src" => "rtsp://www.webiphanycom/video.rm" },
+			   "src" => "rtsp://www.webiphany.com/video.rm" },
 			{ 'region' => $region1,
 			  "src" => "rtsp://www.yahoo.com/radio.rm" } ] );
 			 # 'switch-target' => 36000 } ] );
 $obj->addMedia( "region" => $region1, 
-	       'href' => "http://www.webiphanycom",
+	       'href' => "http://www.webiphany.com",
 	       "src" => "rtsp://realserver/g2video.rm" );
 $obj->addComment( "This is a comment" );
 $obj->addCode( "<RealAdInsert region=\"test\"/>" );
 $obj->addMedia("region" => $region2, 
-	       "anchors" => [ { 'href' => 'http://www.webiphanycom', 
+	       "anchors" => [ { 'href' => 'http://www.webiphany.com', 
 				'coords' => '0,0,23,0' } ],
 	       "src" => "rtsp://realserver/g2video.rm" );
 $obj->endSequence();
